netapp_ontap.models.data_engine_governance_policies_classifier API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.data_engine_governance_policies_classifier`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class DataEngineGovernancePoliciesClassifierSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the DataEngineGovernancePoliciesClassifier object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `create_time: ImpreciseDateTime GET`

    The timestamp indicating when the classifier was created.

    Example: 2018-06-04T19:00:00.000+0000

  `custom: bool GET POST PATCH`

    Indicates if the classifier is custom or predefined.

    Example: false

  `description: str GET POST PATCH`

    Description of the classifier.

    Example: classifier for data subjects(i.e., person names)

  `name: str GET POST PATCH`

    Name of the classifier.

    Example: data subjects classifier

  `state: str GET POST PATCH`

    State of the classifier. Possible values are:

    - enabled: Classifier is enabled.
    - disabled: Classifier is disabled.
    - simulate: Classifier is in simulation mode.

    Valid choices:

    - enabled
    - disabled
    - simulate
  `tag: str GET POST PATCH`

    Tag associated with the classifier.

    Example: CLS_ENTD00000

  `type: str GET POST PATCH`

    Specifies the type of classifier. Possible values are:

    - data: Classifier for data entities.
    - document: Classifier for document entities.

    Valid choices:

    - data
    - document
  `update_time: ImpreciseDateTime GET`

    The timestamp indicating when the classifier was last updated.

    Example: 2018-06-04T19:00:00.000+0000

  `uuid: str GET`

    Unique identifier of the classifier.

    Example: 4ea7a442-86d1-11e0-ae1c-123478563412